==> tecfy_core_package-0.1.17.tar.gz: lib/services/notification_app.service.dart <==
part of tecfy_core_client_package;

class NotificationAppService {
  static bool connected = false;
  static IOWebSocketChannel channel;
  static Stream<dynamic> stream;
  static List<NotificationApp> notificationList = [];
  static int notificationCount = 0;
  static StreamController<int> notificationCountStreamController;
  static Stream<int> notificationCountStream;

  static init() {
    notificationCountStreamController = StreamController<int>();
    notificationCountStream =
        notificationCountStreamController.stream.asBroadcastStream();
    notificationCount = 0;
    getLocalNotifications().then((result) {
      notificationList = result;
      notificationCount = result.length;
      notificationCountStreamController.add(notificationCount);
    });
  }

  static onNotificationReceived(NotificationApp notification) {
    print('Notification Count = $notificationCount');
    if (notificationList.any((n) => n.id == notification.id)) return;
    TimeoutMessage.show(notification.title, message: notification.message);

    if (!notification.showNowOnly) {
      notificationList.insert(0, notification);
      notificationCount++;
      notificationCountStreamController.add(notificationCount);
      saveLocal(notification);
    }
  }

  static softNotifications() {
    notificationList.sort((a, b) => b.time.compareTo(a.time));
    notificationCountStreamController.add(notificationCount);
  }

  static loadOldNotifications() async {
    try {
      var lastMessageTime = await getLastMessageTime();
      if (lastMessageTime == null) {
        lastMessageTime = DateTime.now().subtract(Duration(days: 30));
      }
      print(
          '+++++++++++++++++++++++ geting notification start from $lastMessageTime');
      WebSocketService.sendPackage(
        Package(
            type: PackageType.requestLatestNotification,
            data: lastMessageTime.millisecondsSinceEpoch),
      );
    } catch (err) {
      print(err);
    }
  }

  static Future<DateTime> getLastMessageTime() async {
    var result = await DatabaseService.rawQuery(
        'select time from Notification order by time desc limit 1');
    if (result.length == 0 || result.first['time'] == null) return null;
    return DateTime.fromMillisecondsSinceEpoch(result.first['time'],
        isUtc: true);
  }

  static Future markAsRead(Notification notification) async {
    // TODO: fix the issue
  }

  static Future removeAll() async {
    notificationList = [];
    notificationCount = 0;
    notificationCountStreamController.add(notificationCount);
    await DatabaseService.delete('Notification');
  }

  static Future saveLocal(NotificationApp notification) async {
    try {
      await DatabaseService.insert('Notification', notification.toMapDb());
    } catch (err) {
      print('XXXXXXXXXXXXXXXXXXXXXX cannot save Notification locally!!!!!!!');
      print(err);
    }
  }

  static Future saveLocalAll(List<NotificationApp> notifications) async {
    await DatabaseService.exeBatch((batch) async {
      notifications.forEach((m) => batch.insert('Notification', m.toMapDb()));
      return true;
    },true);
  }

  static Future<List<NotificationApp>> getLocalNotifications() async {
    var list = await DatabaseService.rawQuery(
        "select * from Notification order by time desc");
    return list.map((m) => NotificationApp.fromMap(m)).toList();
  }
}

==> tecfy_core_package-0.1.36.tar.gz: lib/services/notification_app.service.dart <==
part of tecfy_core_client_package;

class NotificationAppService {
  static bool connected = false;
  static IOWebSocketChannel channel;
  static Stream<dynamic> stream;
  static List<NotificationApp> notificationList = [];
  static int notificationCount = 0;
  static StreamController<int> notificationCountStreamController;
  static Stream<int> notificationCountStream;

  static init() {
    notificationCountStreamController = StreamController<int>();
    notificationCountStream =
        notificationCountStreamController.stream.asBroadcastStream();
    notificationCount = 0;
    getLocalNotifications().then((result) {
      notificationList = result;
      notificationCount = result.length;
      notificationCountStreamController.add(notificationCount);
    });
  }

  static onNotificationReceived(NotificationApp notification) {
    print('Notification Count = $notificationCount');
    if (notificationList.any((n) => n.id == notification.id)) return;
    TimeoutMessage.show(notification.title, message: notification.message);

    if (!notification.showNowOnly) {
      notificationList.insert(0, notification);
      notificationCount++;
      notificationCountStreamController.add(notificationCount);
      saveLocal(notification);
    }
  }

  static softNotifications() {
    notificationList.sort((a, b) => b.time.compareTo(a.time));
    notificationCountStreamController.add(notificationCount);
  }

  static loadOldNotifications() async {
    try {
      var lastMessageTime = await getLastMessageTime();
      if (lastMessageTime == null) {
        lastMessageTime = DateTime.now().toUtc().subtract(Duration(days: 30));
      }
      print(
          '+++++++++++++++++++++++ geting notification start from $lastMessageTime');
      WebSocketService.sendPackage(
        Package(
            type: PackageType.requestLatestNotification,
            data: lastMessageTime.millisecondsSinceEpoch),
      );
    } catch (err) {
      print(err);
    }
  }

  static Future<DateTime> getLastMessageTime() async {
    var result = await DatabaseService.rawQuery(
        'select time from Notification order by time desc limit 1');
    if (result.length == 0 || result.first['time'] == null) return null;
    return DateTime.fromMillisecondsSinceEpoch(result.first['time'],
        isUtc: true);
  }

  static Future markAsRead(Notification notification) async {
    // TODO: fix the issue
  }

  static Future removeAll() async {
    notificationList = [];
    notificationCount = 0;
    notificationCountStreamController.add(notificationCount);
    await DatabaseService.delete('Notification');
  }

  static Future saveLocal(NotificationApp notification) async {
    try {
      await DatabaseService.insert('Notification', notification.toMapDb());
    } catch (err) {
      print('XXXXXXXXXXXXXXXXXXXXXX cannot save Notification locally!!!!!!!');
      print(err);
    }
  }

  static Future saveLocalAll(List<NotificationApp> notifications) async {
    await DatabaseService.exeBatch((batch) async {
      notifications.forEach((m) => batch.insert('Notification', m.toMapDb()));
      return true;
    }, true);
  }

  static Future<List<NotificationApp>> getLocalNotifications() async {
    var list = await DatabaseService.rawQuery(
        "select * from Notification order by time desc");
    return list.map((m) => NotificationApp.fromMap(m)).toList();
  }
}
